Module: Rwc::Core
- Defined in:
- lib/rwc/core/context.rb,
lib/rwc/core/base_input.rb,
lib/rwc/core/base_service.rb,
lib/rwc/core/base_decorator.rb,
lib/rwc/core/concerns/validation.rb,
lib/rwc/core/concerns/error_handling.rb
Overview
The Context class is used to encapsulate the result of a service operation, holding information about success, errors, messages, and any relevant payload.
Defined Under Namespace
Modules: Concerns Classes: BaseDecorator, BaseInput, BaseService, Context